@@ -1,4 +1,4 @@
-# import sys
+import lessons.no1 as no1
 def start():
     version = '1.1.2'
     print('Starting Python Teacher v'+version)
@@ -7,7 +7,7 @@ def start():
     q = input('Are you ready to begin learning '+name+'? [yes]: ')
     if 'y' in q.lower():
         print('Time to Learn Python!')
-        #while True
+        no1.start()
     
     # Closing
     print('Closing Python Teacher')
